@@ -1,5 +1,6 @@
 use crate::{handle, AutoRemove};
 use std::io::Write;
+use std::path::Path;
 use tempfile::{NamedTempFile, TempPath};
 
 enum TempfileOrTemppath {
@@ -34,6 +35,36 @@ impl ForksafeTempfile {
             TempfileOrTemppath::Temppath(_) => None,
         }
     }
+    pub fn close(self) -> Self {
+        if let TempfileOrTemppath::Tempfile(file) = self.inner {
+            ForksafeTempfile {
+                inner: TempfileOrTemppath::Temppath(file.into_temp_path()),
+                cleanup: self.cleanup,
+                owning_process_id: self.owning_process_id,
+            }
+        } else {
+            self
+        }
+    }
+    pub fn persist(mut self, path: impl AsRef<Path>) -> Result<Option<std::fs::File>, (std::io::Error, Self)> {
+        match self.inner {
+            TempfileOrTemppath::Tempfile(file) => match file.persist(path) {
+                Ok(file) => Ok(Some(file)),
+                Err(err) => Err((err.error, {
+                    self.inner = TempfileOrTemppath::Tempfile(err.file);
+                    self
+                })),
+            },
+            TempfileOrTemppath::Temppath(temppath) => match temppath.persist(path) {
+                Ok(_) => Ok(None),
+                Err(err) => Err((err.error, {
+                    self.inner = TempfileOrTemppath::Temppath(err.path);
+                    self
+                })),
+            },
+        }
+    }
+
     pub fn into_temppath(self) -> TempPath {
         match self.inner {
             TempfileOrTemppath::Tempfile(file) => file.into_temp_path(),
@@ -52,7 +83,7 @@ impl ForksafeTempfile {
             TempfileOrTemppath::Temppath(path) => path.to_path_buf(),
         };
         let parent_directory = file_path.parent().expect("every tempfile has a parent directory");
-        self.cleanup.execute_best_effort(&parent_directory);
+        self.cleanup.execute_best_effort(parent_directory);
     }
 
     pub fn drop_without_deallocation(self) {
